==> kubernetes-model-autoscaling-5.0.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/MetricStatusFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Object;
import java.util.Map;

public interface MetricStatusFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildExternal instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatus getExternal();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatus buildExternal();
    public A withExternal(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatus external);
    public Boolean hasExternal();
    public MetricStatusFluent.ExternalNested<A> withNewExternal();
    public MetricStatusFluent.ExternalNested<A> withNewExternalLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatus item);
    public MetricStatusFluent.ExternalNested<A> editExternal();
    public MetricStatusFluent.ExternalNested<A> editOrNewExternal();
    public MetricStatusFluent.ExternalNested<A> editOrNewExternalLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildObject instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus getObject();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus buildObject();
    public A withObject(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus object);
    public Boolean hasObject();
    public MetricStatusFluent.ObjectNested<A> withNewObject();
    public MetricStatusFluent.ObjectNested<A> withNewObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus item);
    public MetricStatusFluent.ObjectNested<A> editObject();
    public MetricStatusFluent.ObjectNested<A> editOrNewObject();
    public MetricStatusFluent.ObjectNested<A> editOrNewObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildPods instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatus getPods();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatus buildPods();
    public A withPods(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatus pods);
    public Boolean hasPods();
    public MetricStatusFluent.PodsNested<A> withNewPods();
    public MetricStatusFluent.PodsNested<A> withNewPodsLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatus item);
    public MetricStatusFluent.PodsNested<A> editPods();
    public MetricStatusFluent.PodsNested<A> editOrNewPods();
    public MetricStatusFluent.PodsNested<A> editOrNewPodsLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildResource instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatus getResource();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatus buildResource();
    public A withResource(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatus resource);
    public Boolean hasResource();
    public MetricStatusFluent.ResourceNested<A> withNewResource();
    public MetricStatusFluent.ResourceNested<A> withNewResourceLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatus item);
    public MetricStatusFluent.ResourceNested<A> editResource();
    public MetricStatusFluent.ResourceNested<A> editOrNewResource();
    public MetricStatusFluent.ResourceNested<A> editOrNewResourceLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatus item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);
    public interface ExternalNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatusFluent<MetricStatusFluent.ExternalNested<N>> {

            public N and();
            public N endExternal();    }


    public interface ObjectNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent<MetricStatusFluent.ObjectNested<N>> {

            public N and();
            public N endObject();    }


    public interface PodsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatusFluent<MetricStatusFluent.PodsNested<N>> {

            public N and();
            public N endPods();    }


    public interface ResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatusFluent<MetricStatusFluent.ResourceNested<N>> {

            public N and();
            public N endResource();    }


}

==> kubernetes-model-autoscaling-5.1.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/MetricStatusFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Object;
import java.util.Map;

public interface MetricStatusFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildContainerResource instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus getContainerResource();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus buildContainerResource();
    public A withContainerResource(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus containerResource);
    public Boolean hasContainerResource();
    public MetricStatusFluent.ContainerResourceNested<A> withNewContainerResource();
    public MetricStatusFluent.ContainerResourceNested<A> withNewContainerResourceLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus item);
    public MetricStatusFluent.ContainerResourceNested<A> editContainerResource();
    public MetricStatusFluent.ContainerResourceNested<A> editOrNewContainerResource();
    public MetricStatusFluent.ContainerResourceNested<A> editOrNewContainerResourceLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildExternal instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatus getExternal();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatus buildExternal();
    public A withExternal(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatus external);
    public Boolean hasExternal();
    public MetricStatusFluent.ExternalNested<A> withNewExternal();
    public MetricStatusFluent.ExternalNested<A> withNewExternalLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatus item);
    public MetricStatusFluent.ExternalNested<A> editExternal();
    public MetricStatusFluent.ExternalNested<A> editOrNewExternal();
    public MetricStatusFluent.ExternalNested<A> editOrNewExternalLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildObject instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus getObject();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus buildObject();
    public A withObject(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus object);
    public Boolean hasObject();
    public MetricStatusFluent.ObjectNested<A> withNewObject();
    public MetricStatusFluent.ObjectNested<A> withNewObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus item);
    public MetricStatusFluent.ObjectNested<A> editObject();
    public MetricStatusFluent.ObjectNested<A> editOrNewObject();
    public MetricStatusFluent.ObjectNested<A> editOrNewObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildPods instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatus getPods();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatus buildPods();
    public A withPods(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatus pods);
    public Boolean hasPods();
    public MetricStatusFluent.PodsNested<A> withNewPods();
    public MetricStatusFluent.PodsNested<A> withNewPodsLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatus item);
    public MetricStatusFluent.PodsNested<A> editPods();
    public MetricStatusFluent.PodsNested<A> editOrNewPods();
    public MetricStatusFluent.PodsNested<A> editOrNewPodsLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildResource instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatus getResource();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatus buildResource();
    public A withResource(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatus resource);
    public Boolean hasResource();
    public MetricStatusFluent.ResourceNested<A> withNewResource();
    public MetricStatusFluent.ResourceNested<A> withNewResourceLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatus item);
    public MetricStatusFluent.ResourceNested<A> editResource();
    public MetricStatusFluent.ResourceNested<A> editOrNewResource();
    public MetricStatusFluent.ResourceNested<A> editOrNewResourceLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatus item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);
    public interface ContainerResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<MetricStatusFluent.ContainerResourceNested<N>> {

            public N and();
            public N endContainerResource();    }


    public interface ExternalNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ExternalMetricStatusFluent<MetricStatusFluent.ExternalNested<N>> {

            public N and();
            public N endExternal();    }


    public interface ObjectNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent<MetricStatusFluent.ObjectNested<N>> {

            public N and();
            public N endObject();    }


    public interface PodsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.PodsMetricStatusFluent<MetricStatusFluent.PodsNested<N>> {

            public N and();
            public N endPods();    }


    public interface ResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ResourceMetricStatusFluent<MetricStatusFluent.ResourceNested<N>> {

            public N and();
            public N endResource();    }


}
